package com.rjconsultores.ventaboletos.web.gui.controladores.esquemaoperacional;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Combobox;
import org.zkoss.zul.Comboitem;
import org.zkoss.zul.Intbox;
import org.zkoss.zul.Paging;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.ConfRestricaoCanalVenta;
import com.rjconsultores.ventaboletos.entidad.Parada;
import com.rjconsultores.ventaboletos.entidad.TipoPuntoVenta;
import com.rjconsultores.ventaboletos.service.TipoPuntoVentaService;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderConfRestricaoCanalVenta;

@Controller("confRestricaoCanalVentaController")
@Scope("prototype")
public class BusquedaConfRestricaoCanalVentaController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;
	@Autowired
	private TipoPuntoVentaService tipoPtoVtaService;
	@Autowired
	private transient PagedListWrapper<ConfRestricaoCanalVenta> plwConfRestricaoCanalVenta;
	private MyListbox confRestricaoCanalVentaList;
	private Paging pagingConfRestricaoCanalVenta;
	private List<TipoPuntoVenta> lsTipoPtoVta;
	private Combobox cmbOrigen;
	private Combobox cmbDestino;
	private Combobox cmbTipoPtoVta;
	private Textbox txtDescConf;
	private Intbox txtServico;

	public List<TipoPuntoVenta> getLsTipoPtoVta() {
		return lsTipoPtoVta;
	}

	public void setLsTipoPtoVta(List<TipoPuntoVenta> lsTipoPtoVta) {
		this.lsTipoPtoVta = lsTipoPtoVta;
	}

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		lsTipoPtoVta = tipoPtoVtaService.obtenerTodos();
		super.doAfterCompose(comp);

		confRestricaoCanalVentaList.setItemRenderer(new RenderConfRestricaoCanalVenta());
		confRestricaoCanalVentaList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				ConfRestricaoCanalVenta conf = (ConfRestricaoCanalVenta) confRestricaoCanalVentaList.getSelected();
				verConfRestricaoCanalVenta(conf);
			}
		});

		refreshLista();
	}

	private void refreshLista() {
		HibernateSearchObject<ConfRestricaoCanalVenta> confRestricaoCanalVentaBusqueda =
				new HibernateSearchObject<ConfRestricaoCanalVenta>(ConfRestricaoCanalVenta.class,
						pagingConfRestricaoCanalVenta.getPageSize());

		String desc = txtDescConf.getValue();
		if (!desc.isEmpty()) {
			confRestricaoCanalVentaBusqueda.addFilterLike("descConfRestricaoCanalVenta", desc + "%");
		}

		Integer servicio = txtServico.getValue();
		if (servicio != null) {
			confRestricaoCanalVentaBusqueda.addFilterEqual("corridaId", servicio);
		}

		Comboitem cbiTipoPtoVta = cmbTipoPtoVta.getSelectedItem();
		if (cbiTipoPtoVta != null) {
			TipoPuntoVenta tipoPtoVta = (TipoPuntoVenta) cbiTipoPtoVta.getValue();
			confRestricaoCanalVentaBusqueda.addFilterEqual("tipoPuntoVenta", tipoPtoVta);
		}

		Comboitem cbiOrigem = cmbOrigen.getSelectedItem();
		if (cbiOrigem != null) {
			Parada origem = (Parada) cbiOrigem.getValue();
			confRestricaoCanalVentaBusqueda.addFilterEqual("origem", origem);
		}

		Comboitem cbiDestino = cmbDestino.getSelectedItem();
		if (cbiDestino != null) {
			Parada destino = (Parada) cbiDestino.getValue();
			confRestricaoCanalVentaBusqueda.addFilterEqual("destino", destino);
		}

		confRestricaoCanalVentaBusqueda.addFilterEqual("activo", Boolean.TRUE);
		
		plwConfRestricaoCanalVenta.init(confRestricaoCanalVentaBusqueda, confRestricaoCanalVentaList,
				pagingConfRestricaoCanalVenta);

		if (confRestricaoCanalVentaList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("busquedaCiudadController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void verConfRestricaoCanalVenta(ConfRestricaoCanalVenta conf) {
		if (conf == null) {
			return;
		}

		Map args = new HashMap();
		args.put("confRestricaoCanalVenta", conf);
		args.put("confRestricaoCanalVentaList", confRestricaoCanalVentaList);

		openWindow("/gui/esquema_operacional/editarConfRestricaoCanalVenta.zul",
				Labels.getLabel("editarConfRestricaoCanalVentaController.window.title"),
				args, MODAL);
	}

	public void onClick$btnPesquisa(Event ev) throws InterruptedException {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) {
		verConfRestricaoCanalVenta(new ConfRestricaoCanalVenta());
	}
}
